StripedLock

Struct StripedLock 

pub struct StripedLock<K, H = BuildHasherDefault<DefaultHasher>>
where K: Hash, H: BuildHasher,
{ /* private fields */ }

Implementations

Source

impl<K> StripedLock<K, BuildHasherDefault<DefaultHasher>>
where K: Hash,

pub fn new(locks: NonZeroUsize) -> Self

Create a new StripedLock instance with rust’s default hasher.

Arguments
  • locks - The number of inner locks. Increase to reduce collisions.
Source

impl<K, H> StripedLock<K, H>
where K: Hash, H: BuildHasher,

pub fn with_hasher(hasher_builder: H, locks: NonZeroUsize) -> Self

Create a new StripedLock instance.

Arguments
  • locks - The number of inner locks. Increase to reduce collisions.
  • hasher_builder - The factory of hashers.
pub fn lock(&self, key: K) -> Result<StripedLockGuard<'_>, StripedPoisonError>

Lock on the key. Use lock_batch if you want to lock on multiple keys.

Arguments
  • key - The key to lock on.
pub fn lock_batch<B>( &self, batch: B, ) -> Result<StripedBatchLockGuard<'_>, StripedPoisonError>
where B: KeyBatch<K, H>,

Lock on the key. Use lock_batch if you want to lock on multiple keys.

Arguments
  • batch - The batch of keys to lock on. May be up to 4.
Example
let sl: StripedLock<char> = StripedLock::new(NonZeroUsize::new(4).unwrap());
sl.lock_batch(('a', 'b', 'c', 'd'));
pub fn is_poisoned(&self, key: K) -> bool

Check if the mutex at the given key is poisoned.

pub fn clear_poison(&self, key: K)